py9p
====

Clone of Andrey Mirtchovski's py9p 

 * Documentation: none yet
 * Installation: make install
 * Requirements: Python >= 2.6

You can also use the library without installation, but in this case you
should set up PYTHONPATH manually.

